==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/TransientVarSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.value.TransientVar;
import io.ciera.tool.sql.ooaofooa.value.TransientVarSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class TransientVarSetImpl extends InstanceSet<TransientVarSet,TransientVar> implements TransientVarSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( TransientVar transientvar : this ) transientvar.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( TransientVar transientvar : this ) transientvar.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( TransientVar transientvar : this ) transientvar.setDimensions( m_Dimensions );
    }


    // selections
    @Override
    public V_VARSet R814_is_a_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( TransientVar transientvar : this ) v_varset.add( transientvar.R814_is_a_V_VAR() );
        return v_varset;
    }
    @Override
    public DataTypeSet R821_has_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( TransientVar transientvar : this ) datatypeset.add( transientvar.R821_has_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R844_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( TransientVar transientvar : this ) dimensionsset.addAll( transientvar.R844_may_have_Dimensions() );
        return dimensionsset;
    }


    @Override
    public TransientVar nullElement() {
        return TransientVarImpl.EMPTY_TRANSIENTVAR;
    }

    @Override
    public TransientVarSet emptySet() {
      return new TransientVarSetImpl();
    }

    @Override
    public TransientVarSet value() {
        return this;
    }

    @Override
    public List<TransientVar> elements() {
        return Arrays.asList(toArray(new TransientVar[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/TransientVarSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.value.TransientVar;
import io.ciera.tool.sql.ooaofooa.value.TransientVarSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class TransientVarSetImpl extends InstanceSet<TransientVarSet,TransientVar> implements TransientVarSet {

    public TransientVarSetImpl() {
    }

    public TransientVarSetImpl(Comparator<? super TransientVar> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( TransientVar transientvar : this ) transientvar.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( TransientVar transientvar : this ) transientvar.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( TransientVar transientvar : this ) transientvar.setDimensions( m_Dimensions );
    }


    // selections
    @Override
    public V_VARSet R814_is_a_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( TransientVar transientvar : this ) v_varset.add( transientvar.R814_is_a_V_VAR() );
        return v_varset;
    }
    @Override
    public DataTypeSet R821_has_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( TransientVar transientvar : this ) datatypeset.add( transientvar.R821_has_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R844_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( TransientVar transientvar : this ) dimensionsset.addAll( transientvar.R844_may_have_Dimensions() );
        return dimensionsset;
    }


    @Override
    public TransientVar nullElement() {
        return TransientVarImpl.EMPTY_TRANSIENTVAR;
    }

    @Override
    public TransientVarSet emptySet() {
      return new TransientVarSetImpl();
    }

    @Override
    public TransientVarSet emptySet(Comparator<? super TransientVar> comp) {
      return new TransientVarSetImpl(comp);
    }

    @Override
    public TransientVarSet value() {
        return this;
    }

    @Override
    public List<TransientVar> elements() {
        return Arrays.asList(toArray(new TransientVar[0]));
    }

}
